==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/ts/Draw_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Draw</name>
    <message>
        <location filename="../Draw.js" line="+61"/>
        <source>Draw</source>
        <translation>Dibujar</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Draw</source>
        <translation>&amp;Dibujar</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangle</name>
    <message>
        <source>Top Left</source>
        <translation type="vanished">Arriba izquierda</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="vanished">Parte superior</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="vanished">Arriba derecha</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="vanished">Izquierda</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="vanished">Medio</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="vanished">Derecha</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="vanished">Abajo izquierda</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="vanished">Parte inferior</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="vanished">Abajo derecha</translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="vanished">Posición</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectanglePP</name>
    <message>
        <location filename="../DrawBasedOnRectanglePP.js" line="+63"/>
        <source>First corner</source>
        <translation>Primer punto de esquina</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second corner</source>
        <translation>Segunda punto de esquina</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangleSize</name>
    <message>
        <location filename="../DrawBasedOnRectangleSize.js" line="+46"/>
        <source>Top Left</source>
        <translation>Arriba izquierda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top</source>
        <translation>Parte superior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top Right</source>
        <translation>Arriba derecha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Middle</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Left</source>
        <translation>Abajo izquierda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Parte inferior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Right</source>
        <translation>Abajo derecha</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnThreeCircles</name>
    <message>
        <location filename="../DrawBasedOnThreeCircles.js" line="+72"/>
        <source>First arc or circle</source>
        <translation>Primer arco o círculo</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Second arc or circle</source>
        <translation>Segundo arco o círculo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Third arc or circle</source>
        <translation>Tercero arco o círculo</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/ts/Draw_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Draw</name>
    <message>
        <location filename="../Draw.js" line="+61"/>
        <source>Draw</source>
        <translation>Dibujar</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Draw</source>
        <translation>&amp;Dibujar</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Drawing Tools</source>
        <translation>Herramientas de dibujo</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangle</name>
    <message>
        <source>Top Left</source>
        <translation type="vanished">Arriba izquierda</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="vanished">Parte superior</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="vanished">Arriba derecha</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="vanished">Izquierda</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="vanished">Medio</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="vanished">Derecha</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="vanished">Abajo izquierda</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="vanished">Parte inferior</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="vanished">Abajo derecha</translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="vanished">Posición</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectanglePP</name>
    <message>
        <location filename="../DrawBasedOnRectanglePP.js" line="+69"/>
        <source>First corner</source>
        <translation>Primer punto de esquina</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second corner</source>
        <translation>Segunda punto de esquina</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangleSize</name>
    <message>
        <location filename="../DrawBasedOnRectangleSize.js" line="+46"/>
        <source>Top Left</source>
        <translation>Arriba izquierda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top</source>
        <translation>Parte superior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top Right</source>
        <translation>Arriba derecha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Middle</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Left</source>
        <translation>Abajo izquierda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Parte inferior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Right</source>
        <translation>Abajo derecha</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnThreeCircles</name>
    <message>
        <location filename="../DrawBasedOnThreeCircles.js" line="+72"/>
        <source>First arc or circle</source>
        <translation>Primer arco o círculo</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Second arc or circle</source>
        <translation>Segundo arco o círculo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Third arc or circle</source>
        <translation>Tercero arco o círculo</translation>
    </message>
</context>
</TS>
